@@ -2,17 +2,16 @@
 #' The \code{simList} class
 #'
 #' Contains the minimum components of a \code{SpaDES} simulation.
+#' Various slot accessor methods (i.e., get and set functions) are provided
+#' (see 'Accessor Methods' below).
 #'
 #' Based on code from chapter 7.8.3 of Matloff (2011): "Discrete event simulation".
-#' Here, we implement a discrete event simulation in a more modular fashion so it's
-#' easier to add simulation components (i.e., "simulation modules").
+#' Here, we implement a discrete event simulation in a more modular fashion so
+#' it's easier to add simulation components (i.e., "simulation modules").
 #' We use S4 classes and methods, and use \code{\link{data.table}} instead of
 #' \code{\link{data.frame}} to implement the event queue (because it is much
 #' more efficient).
 #'
-#' Various slot accessor methods (i.e., get and set functions) are provided
-#' (see 'Accessor Methods' below).
-#'
 #' @note The \code{simList} class extends the \code{.simList} superclass by adding
 #' a slot \code{.envir} to store the simulation environment containing references
 #' to simulation objects.
@@ -24,10 +23,11 @@
 #'
 #' @slot modules    List of character names specifying which modules to load.
 #'
-#' @slot params     Named list of potentially other lists specifying simulation parameters.
+#' @slot params     Named list of potentially other lists specifying simulation
+#'                  parameters.
 #'
-#' @slot events     The list of scheduled events (i.e., event queue), as a \code{data.table}.
-#'                  See 'Event Lists' for more information.
+#' @slot events     The list of scheduled events (i.e., event queue), as a
+#'                  \code{data.table}. See 'Event Lists' for more information.
 #'
 #' @slot completed  The list of completed events, as a \code{data.table}.
 #'                  See 'Event Lists' for more information.
@@ -38,24 +38,31 @@
 #' @slot simtimes   List of numerical values describing the simulation start
 #'                  and end times; as well as the current simulation time.
 #'
-#' @slot inputs   The list of length 2: a \code{data.table} or \code{data.table} of files and metadata,
-#' and a list of optional arguments to pass to an import function
+#' @slot inputs     A list of length 2, containing:
+#'                  1) a \code{data.frame} or \code{data.table} of files and
+#'                  metadata, and 2) a list of optional arguments to pass to an
+#'                  import function.
 #'
-#' @slot outputs   The list of length 2: a \code{data.table}  or \code{data.table}  of files and metadata,
-#' and a list of optional arguments to pass to an import function
+#' @slot outputs    A list of length 2 containing:
+#'                  1) a \code{data.frame}  or \code{data.table} of files and
+#'                  metadata, and 2) a list of optional arguments to pass to an
+#'                  export function.
 #'
-#' @slot paths   Named list of \code{modulePath}, \code{inputPath}, and \code{outputPath} paths. Partial
-#' matching is performed.
+#' @slot paths      Named list of \code{modulePath}, \code{inputPath},
+#'                  and \code{outputPath} paths. Partial matching is performed.
 #'
 #' @section Accessor Methods:
 #'
 #' Several slot (and sub-slot) accessor methods are provided for use, and
 #' categorized into separate help pages:
 #' \tabular{ll}{
-#'   \code{\link{simList-accessors-envir}} \tab Simulation enviroment and objects. \cr
+#'   \code{\link{simList-accessors-envir}} \tab Simulation enviroment. \cr
 #'   \code{\link{simList-accessors-events}} \tab Scheduled and completed events. \cr
+#'   \code{\link{simList-accessors-inout}} \tab Passing data in to / out of simulations. \cr
 #'   \code{\link{simList-accessors-modules}} \tab Modules loaded and used; module dependencies. \cr
+#'   \code{\link{simList-accessors-objects}} \tab Accessing objects used in the simulation. \cr
 #'   \code{\link{simList-accessors-params}} \tab Global and module-specific parameters. \cr
+#'   \code{\link{simList-accessors-paths}} \tab File paths for modules, inputs, and outputs. \cr
 #'   \code{\link{simList-accessors-times}} \tab Simulation times. \cr
 #' }
 #'
@@ -67,6 +74,7 @@
 #'   \code{eventTime} \tab The time the event is to occur.\cr
 #'   \code{moduleName} \tab The module from which the event is taken.\cr
 #'   \code{eventType} \tab A character string for the programmer-defined event type.\cr
+#'   \code{eventPriority} \tab The priority given to the event. \cr
 #' }
 #'
 #' @include module-dependencies-class.R
@@ -78,36 +86,45 @@
 #'
 #' @author Alex Chubaty and Eliot McIntire
 #'
-setClass(".simList",
-         slots=list(modules="list", params="list",
-                    events="data.table", completed="data.table",
-                    depends=".simDeps", simtimes="list",
-                    inputs="list", outputs="list",
-                    paths="list"),
-         prototype=list(modules=as.list(NULL),
-                        params=list(.checkpoint=list(interval=NA_real_, file=NULL),
-                                    .progress=list(type=NULL, interval=NULL)),
-                        events=as.data.table(NULL), completed=as.data.table(NULL),
-                        depends=new(".simDeps", dependencies=list(NULL)),
-                        simtimes=list(current=0.00, start=0.00, end=1.00, timeunit=NA_character_),
-                        inputs=data.frame(file=character(0), fun=character(0),
-                                          package=character(0), objectName=character(0),
-                                          loadTime=numeric(0), loaded=logical(0), arg=list(NULL)),
-                        outputs=as.data.frame(NULL),
-                        paths=list(modulePath="./", inputPath="./", outputPath="./")),
-         validity=function(object) {
-           # check for valid sim times
-           if (is.na(object@simtimes$end)) {
-             stop("simulation end time must be specified.")
-           } else {
-             if (object@simtimes$start >= object@simtimes$end) {
-               stop("simulation start time should occur before end time.")
-             }
-           }
+setClass(
+  ".simList",
+  slots = list(
+    modules = "list", params = "list", events = "data.table",
+    completed = "data.table", depends = ".simDeps", simtimes = "list",
+    inputs = "list", outputs = "list", paths = "list"
+  ),
+  prototype = list(
+    modules = as.list(NULL),
+    params = list(
+      .checkpoint = list(interval = NA_real_, file = NULL),
+      .progress = list(type = NULL, interval = NULL)
+    ),
+    events = as.data.table(NULL),
+    completed = as.data.table(NULL),
+    depends = new(".simDeps", dependencies = list(NULL)),
+    simtimes = list(
+      current = 0.00, start = 0.00, end = 1.00, timeunit = NA_character_
+    ),
+    inputs = data.frame(
+      file = character(0), fun = character(0), package = character(0),
+      objectName = character(0), loadTime = numeric(0), loaded = logical(0),
+      arg = list(NULL)
+    ),
+    outputs = as.data.frame(NULL),
+    paths = list(modulePath = "./", inputPath = "./", outputPath = "./")
+  ),
+  validity = function(object) {
+    # check for valid sim times
+    if (is.na(object@simtimes$end)) {
+     stop("simulation end time must be specified.")
+    } else {
+     if (object@simtimes$start >= object@simtimes$end) {
+       stop("simulation start time should occur before end time.")
+     }
+    }
 })
 
 ################################################################################
-#'
 #' @inheritParams .simList
 #'
 #' @slot .envir     Environment referencing the objects used in the simulation.
@@ -122,9 +139,9 @@ setClass(".simList",
 #' @exportClass simList
 #'
 setClass("simList",
-         contains=".simList",
-         slots=list(.envir="environment"),
-         prototype=list(.envir=new.env(parent=emptyenv()))
+         contains = ".simList",
+         slots = list(.envir = "environment"),
+         prototype = list(.envir = new.env(parent = emptyenv()))
 )
 
 ################################################################################
@@ -147,18 +164,18 @@ setClass("simList",
 #' @author Alex Chubaty
 #'
 setClass("simList_",
-         contains=".simList",
-         slots=list(.list="list"),
-         prototype=list(.list=list())
+         contains = ".simList",
+         slots = list(.list = "list"),
+         prototype = list(.list = list())
 )
 
-setAs(from="simList_", to="simList", def=function(from) {
+setAs(from = "simList_", to = "simList", def = function(from) {
   x <- as(as(from, ".simList"), "simList")
   x@.envir <- as.environment(from@.list)
   return(x)
 })
 
-setAs(from="simList", to="simList_", def=function(from) {
+setAs(from = "simList", to = "simList_", def = function(from) {
   x <- as(as(from, ".simList"), "simList_")
   x@.list <- as.list(envir(from))
   return(x)
